#
# spec file for package bino
#
# Copyright (c) 2018 Packman team: http://packman.links2linux.org/
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
# Copyright (c) 2014 Packman team: http://packman.links2linux.org/
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.links2linux.org/
#


%bcond_with     bino_equalizer
Name:           bino
Version:        1.6.7
Release:        2.1
Summary:        Video Player with 3D and Multi-Display Video Support
License:        GPL-2.0+
Group:          Productivity/Multimedia/Video/Players
Url:            http://bino3d.org
ExclusiveArch:  %ix86 x86_64
Source:         https://bino3d.org/releases/bino-%{version}.tar.xz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  info
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
#
BuildRequires:  pkgconfig(libavformat) = 57.83.100
BuildRequires:  pkgconfig(libavdevice) = 57.10.100
BuildRequires:  pkgconfig(libswscale) = 4.8.100
BuildRequires:  pkgconfig(libass)
BuildRequires:  pkgconfig(openal)
BuildRequires:  pkgconfig(Qt5OpenGL)
BuildRequires:  pkgconfig(Qt5Core)
%if %{with bino_equalizer}
BuildRequires:  pkgconfig(Equalizer)
BuildRequires:  pkgconfig(glewmx) >= 1.6.0
%else
BuildRequires:  pkgconfig(glew) >= 1.6.0
%endif
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(lirc)
#
Requires(pre):  hicolor-icon-theme
Requires(pre):  %{install_info_prereq}

%description
Bino is a video player with two special features:
* support for 3D videos, with a wide variety of input and output formats.
* support for multi-display video, e.g. for powerwalls, Virtual Reality
  installations and other multi-projector setups.

%lang_package

%prep
%setup -q

%build
# support via liblircclient
export lirc_CFLAGS="-I%{_includedir}"
export lirc_LIBS="-L%{_libdir} -llirc_client"

autoreconf -fi
%configure \
    --disable-silent-rules \
    %if %{without bino_equalizer}
    --without-equalizer \
    %endif
    --with-qt-version=5
     
%make_build

%install
%make_install

rm -rfv "%{buildroot}%{_datadir}/doc"

%suse_update_desktop_file -r "%{name}" AudioVideo Video Player
%find_lang "%{name}" || echo -n >"%{name}.lang"

%post
%icon_theme_cache_post
%desktop_database_post
%info_add %{name}.info

%postun
%icon_theme_cache_postun
%desktop_database_postun
if [ "$1" = 0 ]; then
  %info_del %{name}.info
fi

%files
%license COPYING
%doc AUTHORS ChangeLog README
%doc doc/*.html doc/*.jpg doc/*.png
%{_bindir}/bino
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/*/*/apps/%{name}.*
%{_mandir}/man1/bino.1%{ext_man}
%{_infodir}/bino.info%{ext_info}

%files lang -f "%{name}.lang"

%changelog
* Thu Oct 11 2018 aloisio@gmx.com
- Update to version 1.6.7
  * Fixed a loop mode problem where the beginning of a video was
    skipped.
  * Fixed building with latest FFmpeg
  * OpenGL stereo output mode is re-enabled with Qt >= 5.10
  version 1.6.6
  * Fixed the preferences dialog for multi-display fullscreen
    mode.
  * Work with plain libglew again, without libglewmx.
- Dropped 0001-Revert-Always-use-GLEWmx-do-not-fall-back-to-GLEW.patch
  and bino-prevent-broken-LIRC-headers.patch (merged upstream)
* Fri May  4 2018 olaf@aepfle.de
- Use ffmpeg3 versions of pkgconfig(libav*)
* Tue Sep 26 2017 zaitor@opensuse.org
- Add bino-prevent-broken-LIRC-headers.patch: Prevent broken LIRC
  headers from messing up PACKAGE_NAME and other definitions.
* Sat Aug  5 2017 olaf@aepfle.de
- Update to 1.6.5
* Sat Oct  8 2016 joerg.lorenzen@ki.tng.de
- Removed service file because build often fails with 'bad temdir'
  and only sometimes succeeds.
* Sat Nov  7 2015 avvissu@yandex.ru
- Build with qt5 on openSUSE 42.1: add %%%%Leap_verSP
- Add language packs
- Add %%%%icon_theme_cache_post(un)
- Add %%%%info_{add,del} instead of %%%%install_info
* Tue May 19 2015 avvissu@yandex.ru
- Fix build on openSUSE > 13.2: use -fPIC instead of -fPIE
* Tue May 12 2015 avvissu@yandex.ru
- Build with Qt5 on openSUE > 13.2
- Add remote control support
- Update the system MIME cache: add %%%%desktop_database_post(un)
* Fri Apr  3 2015 avvissu@yandex.ru
- Fix build on openSUSE > 13.2: use pkgconfig in package names
- Spec file cleanup
* Thu Nov 13 2014 avvissu@yandex.ru
- Update to 1.6.1:
  * the Russian translation was updated
- Add BuildRequires: texinfo
* Fri Oct 24 2014 avvissu@yandex.ru
- Fix installation of the Chinese translation
* Tue Oct  7 2014 avvissu@yandex.ru
- Fix build error on SLES11:
  * add RPM macro %%suse_version
* Sun Oct  5 2014 avvissu@yandex.ru
- update to 1.6.0:
  * add an option to force a specific video aspect ratio,
    and it supports newer versions of important libraries
    (FFmpeg, Qt, Equalizer).
- add supported equalizer (--with-equalizer)
- fix the video player goes into audio player section in kickoff
  menu
* Mon Apr 21 2014 dap.darkness@gmail.com
- Update to 1.4.4:
  * fixes a few bugs;
  * restores compatibility with the latest FFmpeg versions.
- Deleted bino-1.4.2-openal-fix.patch (seems to be unneeded).
- URL tag was updated.
- --with-equalizer requires equalizer-devel that requires
  vmmlib that I failed to package.
- Deleted clean section.
- Switched to download_files service using.
* Thu Feb 28 2013 fisiu@opensuse.org
- Add bino-1.4.2-openal-fix.patch for openSUSE < 12.2
* Sat Feb  9 2013 fisiu@opensuse.org
- Update to 1.4.2:
  * Fix compatibility with the latest FFmpeg versions.
- Drop bino.desktop: use shipped version.
- Drop bino-backport-qvariant.patch: 11.2 is EOL
* Thu Oct 18 2012 pascal.bleser@opensuse.org
- update to 1.4.1:
* Sun Jun 24 2012 pascal.bleser@opensuse.org
- update to 1.4.0:
  * support for the new output mode "Left/right view alternating", also known
    as "frame sequential". This is intended for 120Hz active stereo projectors
    and displays when "OpenGL stereo" is not available.
  * Better support for audio control. Volume, mute, and delay can be adjusted,
    and the output device can be selected.
  * Support for scripting via script files or named pipes.
  * Much improved support for older graphics cards.
  * Support for video output via SDI on NVIDIA Quadro cards.
  * Automatic support for high precision color input and output (30 bits per
    pixel).
  * Single-frame stepping via the '.' key.
  * An adjustable zoom mode for videos that are wider than the screen.
  * Support for opening multiple input devices, and for requesting MJPEG data
    from input devices.
  * Support for the MPO, JPS, and PNS file formats for stereoscopic images.
  * Support for DLP 3-D Ready Sync.
  * Various user interface tweaks, including support for multimedia keyboards
    and a "Recent Files" section in the File menu.
* Sun May 13 2012 pascal.bleser@opensuse.org
- update to 1.3.4:
  * video output: improve quality==0 path
  * documentation: add section about audio/video synchronization
  * video output: make the GL_EXT_texture_sRGB extension optional; now Bino
    runs even on Intel Atom N450 integrated graphics; of course it cannot
    playback 720p or even 576p video, but it runs
  * video output: fix handling of exceptions in render thread
  * documentation: add a section about performance tweaking
  * use cheap GL_RGB8 textures for storing linear RGB data when quality is 0
  * choose RGB linearization/delinearization method based on quality parameter
  * add a new parameter 'quality' for rendering quality / performance tradeoff
  * fix parallax and subtitle parallax adjustment, and take eye swap into
    account
  * relax check for OpenGL version and extensions, to allow older
    implementations
* Tue May  1 2012 pascal.bleser@opensuse.org
- update to 1.3.3:
  * full scripting support
  * better support for older graphics cards
  * support for using two cameras at once
  * support for video output via SDI on NVIDIA Quadro cards
  * additionally, several bugs were fixed
* Sun Mar 18 2012 pascal.bleser@opensuse.org
- update to 1.3.2:
  * several bugs were fixed and compatibility with different systems and
    graphics drivers was improved
  * support for single-frame stepping was added
* Thu Mar 15 2012 pascal.bleser@opensuse.org
- update to 1.3.1:
  * the internal structure was reworked completely, and needs to be tested for
    compatibility with graphics drivers
  * a new output mode, "Left/right view alternating" (also known as "frame
    sequential"), has been added for "3-D Ready" projectors
- changes from 1.3.0:
  * better support for audio control
  * support for high precision color input and output with 30 bits per pixel
  * support for the MPO file format
  * adjustable zoom mode
  * support for multimedia keyboards
  * various user interface tweaks
* Fri Oct 14 2011 pascal.bleser@opensuse.org
- update to 1.2.1:
  * fixes a few bugs, most importantly a frame size problem with some 1080p
    videos
  * Czech translation has been re-enabled
- changes from 1.2.0:
  * flexible fullscreen mode with support for multiple screens
  * support for remote controls via LIRC
  * support for camera devices
  * a loop mode
  * user interface improvements
* Sat Aug 20 2011 pascal.bleser@opensuse.org
- update to 1.1.3:
  * fixes several problems with multi screen support
  * fixes issues with subtitle rendering
- changes from 1.1.2:
  * several updates and user interface improvements were made
* Tue May 24 2011 pascal.bleser@opensuse.org
- update to 1.1.1:
  * adds support for remote controls via LIRC
  * adds a flexible fullscreen mode with support for multiple screens
  * some usability improvements were made
* Tue May 10 2011 pascal.bleser@opensuse.org
- update to 1.1.0:
  * support for camera devices
  * support for selecting the screen to use in fullscreen mode
  * a loop mode
* Thu Apr 28 2011 pascal.bleser@opensuse.org
- update to 1.0.0: first stable release: supports all common 3D video formats,
  3D output methods, and subtitle formats
* Mon Apr 18 2011 pascal.bleser@opensuse.org
- update to 0.9.3:
  * adds support for subtitles in all formats (bitmap, text, SRT, or SSA/ASS)
  * a new stereo-3D output format for 3D TVs is available (HDMI frame packing)
* Tue Mar  8 2011 pascal.bleser@opensuse.org
- update to 0.9.2:
  * fixes various minor problems
  * improves compatibility with some video formats, especially Ogg/Theora
* Sun Feb 27 2011 pascal.bleser@opensuse.org
- update to 0.9.1:
  * fix UTF-8 interpretation of strings
  * new logo
  * Media object: use fixed temporary buffers for audio
  * Media object: improve packet buffering
  * use multithreading to read, decode, and display video data in parallel, for
    better performance
* Wed Feb 23 2011 pascal.bleser@opensuse.org
- update to 0.9.0:
  * support for green/magenta and amber/blue anaglyph glasses was added
  * the implementation of the Dubois anaglyph method was improved
  * all playback parameters can now be changed at any time, including selection
    of video and audio streams and of 3D input and output modes
  * seeking now works with more file formats
* Mon Jan 17 2011 pascal.bleser@opensuse.org
- update to 0.8.1:
  * bugfixes
  * GUI improvements
* Sat Jan  8 2011 pascal.bleser@opensuse.org
- update to 0.8:
  * adds adjustable ghostbusting to reduce crosstalk artifacts
  * adds parallax adjustment
  * adds mouse-based seeking
  * adds initial support for choosing an audio stream
  * improved compatibility with many video types
* Sat Dec 18 2010 pascal.bleser@opensuse.org
- initial package (0.7)
